<?php
/**
 * Plugin Name: DMG Privacy
 * Plugin URI: https://github.com/ANMedia/dmg-privacy-wp-plugin
 * Description: Embed the DMG Privacy Policy information via a WP Shortcode
 * Version: 1.0.0
 */

/**
 * A shortcode to output the privacy policy
 */
class DMG_Privacy_Shortcode {


	/**
	 * Setup the shortcode
	 *
	 * @return void
	 */
	public static function init() {
		add_shortcode( 'dmgprivacy', array( __CLASS__, 'shortcode' ) );
	}

	/**
	 * Add CSS and JS to power the modal
	 *
	 * @return void
	 */
	public static function add_scripts() {
		?>
<style>
#dmg-privacy-popup {
	top: 0;
	left: 0;
	align-content: center;
	padding: 1rem;
	position: fixed;
	width: 100%;
	height: 90vh;
	z-index: 2147483647;
}
#dmg-privacy-closeBtn {
	top: 0;
	background-color: #000;
	width: 100%;
	color: #fff;
	right: 0;
	text-align: right;
	cursor: pointer;
	padding: .5rem;
	font-size: 1rem;
}

#dmg-privacy-popup.dmg-privacy-hidden {
	display: none;
}
</style>
<script type="text/javascript">

document.getElementById('dmg-privacy-submit').addEventListener('click', function(e) {
	e.preventDefault();
	document.getElementById('dmg-privacy-popup').classList.remove('dmg-privacy-hidden');
});
document.getElementById('dmg-privacy-closeBtn').addEventListener('click', function(e) {
	e.preventDefault();
	document.getElementById('dmg-privacy-popup').classList.add('dmg-privacy-hidden');
});
</script>
		<?php
	}

	/**
	 * Shortcode callback
	 *
	 * @param array $atts The shortcode attributes
	 * @return string The HTML markup to output
	 */
	public static function shortcode( $atts ) {
		$atts = shortcode_atts(
			array(
				'id'  => false,
				'url' => 'https://dmgmedia.co.uk/wp-json/wp/v2/privacy-policy/',
			),
			$atts
		);

		add_action( 'wp_footer', array( __CLASS__, 'add_scripts' ) );

		$markup = '<div class="dmg-privacy">';

		$markup .= '<h2>Last updated: ' . date( 'd F Y' ) . '</h2>';
		if ( empty( $atts['id'] ) ) {
			$markup .= '<!-- No ID Provided -->';
		} else {
			$cached_data = get_transient( 'dmgmedia_privacy' );
			if ( ! empty( $cached_data ) ) {
				$data = $cached_data;
			} else {
				$url      = $atts['url'] . $atts['id'];
				$response = wp_remote_get( $url );
				$body     = wp_remote_retrieve_body( $response );
				$data     = json_decode( $body );
			}
			if ( ! is_wp_error( $data ) && ! empty( $data ) ) {

				$iframe_src = ( ! empty( $data->acf->dsr_form_url ) ) ? $data->acf->dsr_form_url : '';
				$popup_html = "<div id='dmg-privacy-popup' class='dmg-privacy-hidden'><div id='dmg-privacy-closeBtn'>Close</div><iframe src='$iframe_src' height='100%' width='100%'></iframe></div>";
				$markup    .= $popup_html;

				$popup_button = "<a href='$iframe_src' id='dmg-privacy-submit'>Submit Data Subject Request</a>";
				$markup      .= $popup_button;

				$privacy_markup = '';
				if ( ! empty( $data->acf->privacypolicy ) ) {
					foreach ( $data->acf->privacypolicy as $block ) {
						$title           = wp_kses_post( $block->tab_title );
						$privacy_markup .= "<h2>$title</h2>";
						$content         = wp_kses_post( $block->tab_content );
						$privacy_markup .= "<p>$content</p>";
					}
				}
				$markup .= $privacy_markup;
				set_transient( 'dmgmedia_privacy', $data, HOUR_IN_SECONDS );
			} else {
				$markup .= "<!-- Error requesting $url -->";
			}
		}

		$markup .= '</div>';

		return $markup;

	}
}

DMG_Privacy_Shortcode::init();

